+++
title = "Routines List"
order = 2
+++


List on routines implemented in BLASFEO for a reference about the namining
conventions adopted see [Naming Conventions](/docs/naming)



## blas1
 - blasfeo\_(s|d)axpy
 - blasfeo\_(s|d)axpby
 - blasfeo\_(s|d)vecmul
 - blasfeo\_(s|d)vecmulacc
 - blasfeo\_(s|d)vecmuldot
 - blasfeo\_(s|d)dot
 - blasfeo\_(s|d)rotg
 - blasfeo\_(s|d)colrot
 - blasfeo\_(s|d)rowrot




## blas2
 - blasfeo\_(s|d)gemv\_n
 - blasfeo\_(s|d)gemv\_t
 - blasfeo\_(s|d)gemv\_d
 - blasfeo\_(s|d)gemv\_nt
 - blasfeo\_(s|d)symv\_l\_nt
 - blasfeo\_(s|d)trsv\_lnn\_mn
 - blasfeo\_(s|d)trsv\_ltn\_mn
 - blasfeo\_(s|d)trsv\_lnn
 - blasfeo\_(s|d)trsv\_lnu
 - blasfeo\_(s|d)trsv\_ltn
 - blasfeo\_(s|d)trsv\_unn
 - blasfeo\_(s|d)trsv\_utn
 - blasfeo\_(s|d)trsm\_unn
 - blasfeo\_(s|d)trsm\_utn
 - blasfeo\_(s|d)trsm\_lnn
 - blasfeo\_(s|d)trsm\_ltn




## blas3
 - blasfeo\_(s|d)gemm\_nn
 - blasfeo\_(s|d)gemm\_nt
 - blasfeo\_(s|d)gemm\_dn
 - blasfeo\_(s|d)gemm\_nd
 - blasfeo\_(s|d)syrk\_ln\_mn
 - blasfeo\_(s|d)syrk\_ln
 - blasfeo\_(s|d)trsm\_llnu
 - blasfeo\_(s|d)trsm\_rltu
 - blasfeo\_(s|d)trsm\_rltn
 - blasfeo\_(s|d)trsm\_lunn
 - blasfeo\_(s|d)trsm\_rutn
 - blasfeo\_(s|d)trmm\_rutn
 - blasfeo\_(s|d)trmm\_rlnn
 - blasfeo\_(s|d)dia\_left\_ib




## lapack
 - blasfeo\_(s|d)potrf\_l
 - blasfeo\_(s|d)potrf\_l\_mn
 - blasfeo\_syrk\_(s|d)potrf\_l\_ln
 - blasfeo\_(s|d)getrf\_nopivot
 - blasfeo\_(s|d)getrf\_rowpivot
 - blasfeo\_(s|d)geqrf
 - blasfeo\_(s|d)geqrf\_worksize
 - blasfeo\_(s|d)gelqf
 - blasfeo\_(s|d)gelqf\_worksize
 - blasfeo\_(s|d)gelqf\_pd
 - blasfeo\_(s|d)gelqf\_pd\_la
 - blasfeo\_(s|d)gelqf\_pd\_lla




## aux
 - blasfeo\_(s|d)gesc
 - blasfeo\_(s|d)gecp
 - blasfeo\_(s|d)gead
 - blasfeo\_(s|d)gecpsc
 - blasfeo\_(s|d)trcp\_l
 - blasfeo\_(s|d)trcpsc
 - blasfeo\_(s|d)trsc\_l
 - blasfeo\_(s|d)trtr\_l
 - blasfeo\_(s|d)trtr\_u
 - blasfeo\_(s|d)diare
 - blasfeo\_(s|d)diain
 - blasfeo\_(s|d)diain\_sp
 - blasfeo\_(s|d)diaex
 - blasfeo\_(s|d)diaex\_sp
 - blasfeo\_(s|d)diaad
 - blasfeo\_(s|d)diaad\_sp
 - blasfeo\_(s|d)diaadin\_sp
 - blasfeo\_(s|d)rowin
 - blasfeo\_(s|d)rowex
 - blasfeo\_(s|d)rowad
 - blasfeo\_(s|d)rowad\_sp
 - blasfeo\_(s|d)rowsw
 - blasfeo\_(s|d)rowpe
 - blasfeo\_(s|d)rowpei
 - blasfeo\_(s|d)colin
 - blasfeo\_(s|d)colex
 - blasfeo\_(s|d)colsw
 - blasfeo\_(s|d)colpe
 - blasfeo\_(s|d)colpei
 - blasfeo\_(s|d)vecse
 - blasfeo\_(s|d)veccp
 - blasfeo\_(s|d)vecsc
 - blasfeo\_(s|d)veccpsc
 - blasfeo\_(s|d)vecin1
 - blasfeo\_(s|d)vecex1
 - blasfeo\_(s|d)vecin\_sp
 - blasfeo\_(s|d)vecad
 - blasfeo\_(s|d)vecad\_sp
 - blasfeo\_(s|d)vecex\_sp
 - blasfeo\_(s|d)vecsw
 - blasfeo\_(s|d)veccl
 - blasfeo\_(s|d)veccl\_mask
 - blasfeo\_(s|d)vecze
 - blasfeo\_(s|d)vecnrm\_inf
 - blasfeo\_(s|d)vecpe
 - blasfeo\_(s|d)vecpei
 - blasfeo\_memsize\_(s|d)mat
 - blasfeo\_memsize\_diag\_(s|d)mat
 - blasfeo\_memsize\_(s|d)vec
 - blasfeo\_create\_(s|d)mat
 - blasfeo\_create\_(s|d)vec
 - blasfeo\_pack\_(s|d)mat
 - blasfeo\_pack\_tran\_(s|d)vec
 - blasfeo\_unpack\_(s|d)mat
 - blasfeo\_unpack\_tran\_(s|d)mat
 - blasfeo\_unpack\_(s|d)vec
 - blasfeo\_(s|d)\_cast\_mat2strmat
 - blasfeo\_(s|d)\_cast\_diag\_mat2strmat
 - blasfeo\_(s|d)\_cast\_vec2vecmat


